// naumann@stce.rwth-aachen.de

#include <iostream> 
#include <cmath> 
#include <limits>


template<typename T>
T model(T p, T x) { return pow(p*x,2); }

template<typename T>
T e(T p, T x1, T y1, T x2, T y2) {
  return pow(model(p,x1)-y1,2)+pow(model(p,x2)-y2,2);
}

template<typename T>
T dedp(T p, T x1, T y1, T x2, T y2) {
  const T eps=std::numeric_limits<T>::epsilon();
  const T h=(p!=0) ? sqrt(sqrt(eps))*fabs(p) : sqrt(sqrt(eps));
  return (e(p+h,x1,y1,x2,y2)-e(p-h,x1,y1,x2,y2))/(2*h);
}

template<typename T>
T ddedpp(T p, T x1, T y1, T x2, T y2) {
  const T eps=std::numeric_limits<T>::epsilon();
  const T h=(p!=0) ? sqrt(sqrt(eps))*fabs(p) : sqrt(sqrt(eps));
  return (dedp(p+h,x1,y1,x2,y2)-dedp(p-h,x1,y1,x2,y2))/(2*h);
}

template<typename T>
T estimate(T x1, T y1, T x2, T y2) {
  const T eps=std::numeric_limits<T>::epsilon();
  T p=42;
  T d=dedp(p,x1,y1,x2,y2);
  while (fabs(d)>sqrt(eps)) {
    p-=d/ddedpp(p,x1,y1,x2,y2);
    d=dedp(p,x1,y1,x2,y2);
  }
  return p;
}

int main() {
  using namespace std;
  double x1=0,x2=0,y1=0,y2=0;
  cout << "x1="; cin >> x1; cout << "y1="; cin >> y1;
  cout << "x2="; cin >> x2; cout << "y2="; cin >> y2;
  cout << estimate(x1,y1,x2,y2) << endl;
  return 0;
}
